API Reference — mosaik 2.1.2 documentation

# API Reference

The API reference provides detailed descriptions of mosaik’s classes and functions. It should be helpful if you plan to extend mosaik with custom components.

- `mosaik` — The ende-user API
- `mosaik.exceptions` — mosaik specific error types
- `mosaik.scenario` — Classes related to the scenario creation
- `mosaik.scheduler` — Coordinate and execute simulators
- `mosaik.simmanager` — Management of external processes
- `mosaik.util` — Utility classes and functions